==> qtjambi-remoteobjects-debuginfo-macos-5.15.17.jar: sources/QtJambiRemoteObjects/QRemoteObjectRegistry_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtCore/QVariant>
#include <QtCore/QHash>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtCore/qpair.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtCore/QList>
#include <QtCore/qbytearray.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qcoreevent.h>
#include <QtCore/qthread.h>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QRemoteObjectRegistry_0(){
    static int result = QMetaMethod::fromSignal(&QRemoteObjectRegistry::remoteObjectAdded).methodIndex();
    return result;
}


int __signal_method_indexes_QRemoteObjectRegistry_1(){
    static int result = QMetaMethod::fromSignal(&QRemoteObjectRegistry::remoteObjectRemoved).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QRemoteObjectRegistry::sourceLocations()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectRegistry_sourceLocations_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectRegistry *__qt_this = QtJambiAPI::objectFromNativeId<QRemoteObjectRegistry>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectRegistry::sourceLocations()const", __qt_this)
        QHash<QString, QRemoteObjectSourceLocationInfo> __qt_return_value = __qt_this->sourceLocations();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectRegistry::registerMetatypes()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectRegistry_registerMetatypes__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectRegistry::registerMetatypes()")
    QTJAMBI_TRY {
        QRemoteObjectRegistry::registerMetatypes();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QRemoteObjectNode
bool nativeToJavaConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QRemoteObjectNode

void initialize_meta_info_QRemoteObjectRegistry(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QRemoteObjectRegistry>("QRemoteObjectRegistry", "io/qt/remoteobjects/QRemoteObjectRegistry");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QRemoteObjectRegistry::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "remoteObjectAdded", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QRemoteObjectRegistry_0),
                SignalMetaInfo(/* 1 */ "remoteObjectRemoved", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QRemoteObjectRegistry_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QRemoteObjectRegistry_0()){ // remoteObjectAdded(const QPair<QString, QRemoteObjectSourceLocationInfo> & entry)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QPair<QString, QRemoteObjectSourceLocationInfo>&
                                method.parameterType(0),
                                "io/qt/core/QPair",
                                &nativeToJavaConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref,
                                &javaToNativeConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QRemoteObjectRegistry_1()){ // remoteObjectRemoved(const QPair<QString, QRemoteObjectSourceLocationInfo> & entry)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QPair<QString, QRemoteObjectSourceLocationInfo>&
                                method.parameterType(0),
                                "io/qt/core/QPair",
                                &nativeToJavaConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref,
                                &javaToNativeConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerMetaType<QPair<QString, QRemoteObjectSourceLocationInfo>>("QPair<QString, QRemoteObjectSourceLocationInfo>");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-remoteobjects-debuginfo-macos-6.5.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectRegistry_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtCore/QVariant>
#include <QtCore/QHash>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtCore/qproperty.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qbytearray.h>
#include <QtCore/QList>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/qobject.h>
#include <QtCore/qtimer.h>
#include <QtCore/qcoreevent.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qmetaobject.h>
#include <QtCore/qthread.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QRemoteObjectRegistry_0(){
    static int result = QMetaMethod::fromSignal(&QRemoteObjectRegistry::remoteObjectAdded).methodIndex();
    return result;
}


int __signal_method_indexes_QRemoteObjectRegistry_1(){
    static int result = QMetaMethod::fromSignal(&QRemoteObjectRegistry::remoteObjectRemoved).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QRemoteObjectRegistry::bindableSourceLocations()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectRegistry_bindableSourceLocations_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectRegistry *__qt_this = QtJambiAPI::objectFromNativeId<QRemoteObjectRegistry>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectRegistry::bindableSourceLocations()const", __qt_this)
        QBindable<QHash<QString, QRemoteObjectSourceLocationInfo> > __qt_return_value = __qt_this->bindableSourceLocations();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectRegistry::sourceLocations()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectRegistry_sourceLocations_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectRegistry *__qt_this = QtJambiAPI::objectFromNativeId<QRemoteObjectRegistry>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectRegistry::sourceLocations()const", __qt_this)
        QHash<QString, QRemoteObjectSourceLocationInfo> __qt_return_value = __qt_this->sourceLocations();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectRegistry::registerMetatypes()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectRegistry_registerMetatypes__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectRegistry::registerMetatypes()")
    QTJAMBI_TRY {
        QRemoteObjectRegistry::registerMetatypes();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QRemoteObjectNode
bool nativeToJavaConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QRemoteObjectNode

void initialize_meta_info_QRemoteObjectRegistry(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QRemoteObjectRegistry>("QRemoteObjectRegistry", "io/qt/remoteobjects/QRemoteObjectRegistry");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QRemoteObjectRegistry::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "remoteObjectAdded", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QRemoteObjectRegistry_0),
                SignalMetaInfo(/* 1 */ "remoteObjectRemoved", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QRemoteObjectRegistry_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QRemoteObjectRegistry_0()){ // remoteObjectAdded(const QPair<QString, QRemoteObjectSourceLocationInfo> & entry)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QPair<QString, QRemoteObjectSourceLocationInfo>&
                                method.parameterType(0),
                                "io/qt/core/QPair",
                                &nativeToJavaConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref,
                                &javaToNativeConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QRemoteObjectRegistry_1()){ // remoteObjectRemoved(const QPair<QString, QRemoteObjectSourceLocationInfo> & entry)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QPair<QString, QRemoteObjectSourceLocationInfo>&
                                method.parameterType(0),
                                "io/qt/core/QPair",
                                &nativeToJavaConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref,
                                &javaToNativeConverter_QPair_lt_QString_QRemoteObjectSourceLocationInfo_gt_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerMetaType<QPair<QString, QRemoteObjectSourceLocationInfo>>("QPair<QString, QRemoteObjectSourceLocationInfo>");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
